@@ -107,3 +107,28 @@
 #' @family built-in timescales
 #' @source <https://stratigraphy.org> via <https://macrostrat.org/api/v2/defs/intervals?timescale=international%20ages>
 "stages"
+
+#' Pattern numbers and names for patterns from the FGDC Digital Cartographic
+#' Standard for Geologic Map Symbolization
+#'
+#' A dataset containing the FGDC pattern numbers and verbatim names from the
+#' [FGDC Digital Cartographic Standard for Geologic Map
+#' Symbolization](https://ngmdb.usgs.gov/fgdc_gds/geolsymstd.php) by the [U.S.
+#' Geological Survey](https://www.usgs.gov/) and the [Geologic Data Subcommittee
+#' (GDS)](https://ngmdb.usgs.gov/fgdc_gds/index.php) of the [Federal Geographic
+#' Data Committee (FGDC)](https://www.fgdc.gov/). Only patterns with names are
+#' included (i.e., patterns 601-733).
+#'
+#' These pattern numbers and names were originally extracted by Daven Quinn and
+#' are hosted on [GitHub](https://github.com/davenquinn/geologic-patterns/).
+#'
+#' @format A data frame with 117 rows and 2 variables:
+#' \describe{
+#'   \item{code}{the pattern number according to the FGDC standard}
+#'   \item{name}{the verbatim name for the pattern according to the FGDC standard}
+#' }
+#' @family patterns
+#' @source
+#'   <https://ngmdb.usgs.gov/fgdc_gds/geolsymstd/fgdc-geolsym-patternchart.pdf>
+#'   via <https://github.com/davenquinn/geologic-patterns/>
+"fgdc_names"
