@@ -109,6 +109,7 @@ get_scale_data <- function(name, true_colors = TRUE) {
     clean_dat$abbr[no_abbr] <-
       abbreviate(clean_dat$name, minlength = 1,
                  use.classes = TRUE, named = FALSE)[no_abbr]
+    clean_dat$abbr[clean_dat$name == "Stage 10"] <- "S10" # fix abbreviation
     dat <- clean_dat
     dat$lab_color <- white_or_black(dat$color)
   }
@@ -134,16 +135,3 @@ macrostrat_timescales <- function() {# nocov start
                      stringsAsFactors = FALSE)
   return(paste0("\\item ", scales$timescale, collapse = "\n"))
 }# nocov end
-
-#' Get geological timescale data
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' `getScaleData()` was renamed to [get_scale_data()] as of **deeptime** version
-#' 1.0.0 to create a more consistent API.
-#' @keywords internal
-#' @export
-getScaleData <- function(name) {
-  lifecycle::deprecate_stop("1.0.0", "getScaleData()", "get_scale_data()")
-}
